from django.contrib import admin

from .models import UserAccount


@admin.register(UserAccount)
class UserAccountAdmin(admin.ModelAdmin):
    fieldsets = (
        (None, {'fields': ('email', 'account_name', 'account_type')}),
        (
            "Permissions",
            {
                'fields': (
                    'is_active',
                    'is_superuser',
                    'groups',
                    'user_permissions',
                )
            },
        ),
        ("Dates importantes", {'fields': ('last_login', 'date_joined')}),
    )
    list_display = ('email', 'full_name', 'is_active', 'is_superuser')
    list_filter = ('is_superuser', 'is_active', 'groups')
    readonly_fields = (
        'account_name',
        'account_type',
        'last_login',
        'date_joined',
    )

    def account_name(self, account):
        return account.get_full_name()

    account_name.short_description = "Nom"

    def account_type(self, account):
        if account.details is not None:
            return '{} : {}'.format(
                account.type_info.verbose_name.title(), account.details
            )
        return '-'

    account_type.short_description = "Type de compte"
