from django.conf import settings
from django.core.mail import send_mail
from django.template.loader import render_to_string

from registration.signals import user_activated

from .models import UserAccount


def user_activated_notify(user, request, **kwargs):
    """
    Notifie les administrateurs de l'activation d'un nouveau compte.
    """
    to_emails = UserAccount.objects.admins().values_list('email', flat=True)
    if not to_emails:
        return

    context = {
        'user': user,
        'protocol': request.scheme,
        'domain': request.get_host(),
        'user_details_url': user.get_admin_details_url(),
    }
    subject = render_to_string(
        'registration/activated_notify_subject.txt', context
    )
    subject = ''.join(subject.splitlines())
    message_txt = render_to_string(
        'registration/activated_notify_email.txt', context
    )
    message_html = render_to_string(
        'registration/activated_notify_email.html', context
    )

    send_mail(
        subject,
        message_txt,
        settings.DEFAULT_FROM_EMAIL,
        to_emails,
        html_message=message_html,
    )


def register_signal_handlers():
    user_activated.connect(user_activated_notify)
