from django.urls import path
from django.views.generic.base import TemplateView

from .views import (
    ActivationView,
    LoginView,
    LogoutView,
    PasswordResetConfirmView,
    PasswordResetView,
    RegistrationView,
    ResendActivationView,
)

app_name = 'accounts'

urlpatterns = [
    # Connexion et gestion du compte ------------------------------------------
    # https://docs.djangoproject.com/en/stable/topics/auth/default/#module-django.contrib.auth.views
    path('login/', LoginView.as_view(), name='login'),
    path('logout/', LogoutView.as_view(), name='logout'),
    path('password/reset/',
         PasswordResetView.as_view(),
         name='password_reset'),
    path('password/reset/confirm/<uidb64>/<token>/',
         PasswordResetConfirmView.as_view(),
         name='password_reset_confirm'),

    # Enregistrement et activation du compte ----------------------------------
    # https://github.com/macropin/django-registration/blob/master/registration/backends/default/urls.py
    path('activate/resend/',
         ResendActivationView.as_view(),
         name='registration_resend_activation'),
    path('activate/<activation_key>/',
         ActivationView.as_view(),
         name='registration_activate'),
    path('register/complete/',
         TemplateView.as_view(
             template_name='registration/registration_complete.html'),
         name='registration_complete'),
    path('register/closed/',
         TemplateView.as_view(
             template_name='registration/registration_closed.html'),
         name='registration_disallowed'),
    path('register/',
         TemplateView.as_view(
             template_name='registration/registration_index.html'),
         name='registration_register'),
    path('register/<type_name>/',
         RegistrationView.as_view(
             success_url='accounts:registration_complete',
             disallowed_url='accounts:registration_disallowed'),
         name='registration_register'),
]
