from django import forms

from tapeforms.fieldsets import TapeformFieldset


class AdresseFormMixin:
    """
    Étends le formulaire d'un modèle contenant une adresse.
    """

    code_postal = forms.RegexField(
        label="Code postal",
        min_length=5,
        max_length=5,
        regex=r'^\d{5}$',
        error_messages={'invalid': "Saisissez un code postal au format XXXXX."},
    )

    class Meta:
        fields = ('rue', 'code_postal', 'ville', 'geolocalisation')

    def adresse_fieldset(self):
        """Retourne l'objet `TapeformFieldset` à utiliser pour l'adresse."""
        return TapeformFieldset(
            self,
            fields=AdresseFormMixin.Meta.fields,
            template='base/forms/layouts/adresse.html',
        )
