from django.core.exceptions import ValidationError

import pytest

from .models import OptionalAdresse, RequiredAdresse


@pytest.mark.django_db
class TestAdresseMixin:
    def test_adresse(self):
        adresse = RequiredAdresse(
            rue="3 rue des champs", ville="Libreville", code_postal='01000'
        )
        assert adresse.adresse == "3 rue des champs, 01000 Libreville"
        assert adresse.get_adresse_display() == (
            "3 rue des champs<br>01000 Libreville"
        )

    def test_not_adresse(self):
        adresse = OptionalAdresse()
        assert adresse.adresse == ''
        assert adresse.get_adresse_display() == ''

    def test_latitude_longitude(self):
        adresse = RequiredAdresse()
        assert adresse.latitude == ''
        assert adresse.longitude == ''

        adresse.geolocalisation = '1,2'
        assert adresse.latitude == '1'
        assert adresse.longitude == '2'

    def test_clear_adresse(self):
        adresse = RequiredAdresse(
            rue="3 rue des champs",
            ville="Libreville",
            code_postal='01000',
            geolocalisation='1,1',
        )
        assert adresse.has_adresse is True
        assert adresse.is_geolocated is True

        adresse.clear_adresse()
        assert adresse.has_adresse is False
        assert adresse.is_geolocated is False

    def test_clean_required(self):
        adresse = RequiredAdresse()
        adresse.clean()

    def test_clean_optional(self):
        adresse = OptionalAdresse()
        adresse.clean()

        adresse.rue = "3 rue des champs"
        with pytest.raises(ValidationError):
            adresse.clean()

        adresse.ville = "Libreville"
        adresse.code_postal = '01000'
        adresse.clean()

    def test_clean_optional_geolocalisation(self):
        adresse = OptionalAdresse(geolocalisation='1,1')
        assert adresse.is_geolocated is True

        adresse.clean()
        assert adresse.is_geolocated is False
