from django.utils.html import format_html

from wagtail import hooks
from wagtail.admin.menu import MenuItem

from .templatetags.minified import minified


@hooks.register('insert_global_admin_css')
def global_admin_css():
    """Ajoute une feuille de styles personnalisée dans l'admin."""
    return format_html(
        '<link rel="stylesheet" href="{}">', minified('css/admin.css')
    )


@hooks.register('register_icons')
def custom_icons(icons):
    for icon in [
        'bullhorn',
        'graduation-cap',
        'ticket',
        'cubes',
        'tags',
        'list',
    ]:
        icons.append('admin/icons/{}.svg'.format(icon))
    return icons


@hooks.register('register_admin_menu_item')
def register_site_menu_item():
    """Ajoute un élément de menu pour retourner vers le site."""
    return SiteMenuItem(classnames='icon icon-home', order=10000)


class SiteMenuItem(MenuItem):
    """Élément de menu pour retourner vers le site."""

    def __init__(self, label="Retour au site", url='', **kwargs):
        super().__init__(label, '', **kwargs)

    def is_active(self, *args, **kwargs):
        return False

    def get_context(self, request):
        context = super().get_context(request)
        context['url'] = request.META['SCRIPT_NAME'] or '/'
        return context
