# Generated by Django 2.0.6 on 2018-06-26 11:40

import django.db.models.deletion
from django.db import migrations

import modelcluster.fields


def convert_annoncepage_to_annonce(apps, schema_editor):
    Annonce = apps.get_model('echanges', 'Annonce')
    AnnoncePage = apps.get_model('echanges', 'AnnoncePage')
    db_alias = schema_editor.connection.alias
    # crée les objets Annonce depuis les AnnoncePage
    annonce_objects = []
    for page in AnnoncePage.objects.using(db_alias).all():
        annonce = Annonce(**{attr: getattr(page, attr) for attr in [
            'title', 'type', 'description', 'category', 'owner',
        ]})
        annonce.id = page.pk
        annonce.is_active = page.live
        annonce.created_at = (page.first_published_at or
                              page.latest_revision_created_at)
        annonce.last_modified_at = page.latest_revision_created_at
        annonce_objects.append(annonce)
    Annonce.objects.using(db_alias).bulk_create(annonce_objects)


def create_settings_from_annonceindexpage(apps, schema_editor):
    AnnonceIndexPage = apps.get_model('echanges', 'AnnonceIndexPage')
    EchangesSettings = apps.get_model('echanges', 'Settings')
    Site = apps.get_model('wagtailcore', 'Site')
    db_alias = schema_editor.connection.alias
    # récupère la première page d'index pour peupler les paramètres
    index_page = AnnonceIndexPage.objects.using(db_alias).first()
    if index_page is not None:
        EchangesSettings.objects.using(db_alias).create(
            site=Site.objects.using(db_alias).first(),
            introduction=index_page.introduction,
            help_content=index_page.details,
            help_is_active=(
                index_page.details is not None and
                index_page.details.strip() != ''
            ),
        )


def delete_echanges_pages(apps, schema_editor):
    Page = apps.get_model('wagtailcore', 'Page')
    ContentType = apps.get_model('contenttypes', 'ContentType')
    db_alias = schema_editor.connection.alias
    # supprime toutes les pages AnnoncePage et AnnonceIndexPage ainsi que les
    # types de contenu associés à ces modèles
    content_types = ContentType.objects.using(db_alias).filter(
        app_label='echanges', model__in=['annoncepage', 'annonceindexpage'])
    for page in Page.objects.using(db_alias).filter(
            content_type__in=content_types):
        page.delete()
    content_types.delete()


class Migration(migrations.Migration):

    dependencies = [
        ('echanges', '0003_create_annonce_settings'),
    ]

    operations = [
        migrations.RunPython(convert_annoncepage_to_annonce),
        migrations.RunPython(create_settings_from_annonceindexpage),
        migrations.AlterField(
            model_name='annoncephoto',
            name='annonce',
            field=modelcluster.fields.ParentalKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name='photos',
                to='echanges.Annonce'
            ),
        ),
        migrations.RunPython(delete_echanges_pages),
    ]
