import pytest

from boiteaasso.accounts.tests_accounts.factories import (
    AssociationFactory,
    UserAccountFactory,
)

from .factories import AnnonceFactory


@pytest.mark.django_db
class TestAnnoncePermissionTester:
    def setup_method(self):
        self.annonce = AnnonceFactory()

    def test_owner_permissions(self):
        tester = self.annonce.permissions_for_user(self.annonce.owner)
        assert tester.is_owner()
        assert tester.can_edit()
        assert tester.can_delete()
        assert not tester.can_contact()

    def test_association_permissions(self):
        tester = self.annonce.permissions_for_user(AssociationFactory().account)
        assert not tester.is_owner()
        assert not tester.can_edit()
        assert not tester.can_delete()
        assert tester.can_contact()

    def test_user_permissions(self):
        tester = self.annonce.permissions_for_user(UserAccountFactory())
        assert not tester.is_owner()
        assert not tester.can_edit()
        assert not tester.can_delete()
        assert not tester.can_contact()

    def test_admin_permissions(self):
        tester = self.annonce.permissions_for_user(
            UserAccountFactory(
                permissions__codenames=['change_annonce', 'delete_annonce']
            )
        )
        assert not tester.is_owner()
        assert tester.can_edit()
        assert tester.can_delete()
        assert not tester.can_contact()
