# Generated by Django 2.2.16 on 2020-10-20 09:38

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import dynamic_filenames
import location_field.models.plain
import modelcluster.fields
import stdimage.models
import wagtail.core.fields
import wagtail.search.index


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0008_personne'),
        ('wagtailcore', '0041_group_collection_permissions_verbose_name_plural'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='OffreEmploi',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rue', models.CharField(blank=True, max_length=100, verbose_name='rue')),
                ('ville', models.CharField(blank=True, max_length=100, verbose_name='ville')),
                ('code_postal', models.CharField(blank=True, max_length=5, verbose_name='code postal')),
                ('geolocalisation', location_field.models.plain.PlainLocationField(blank=True, help_text="Le marqueur est initié en fonction de l'adresse, déplacez le pour affiner la position. Vous pouvez zoomer ou dézoomer avec la molette de la souris.", max_length=63, verbose_name='géolocalisation')),
                ('title', models.CharField(max_length=255, verbose_name='titre')),
                ('type', models.CharField(choices=[('offre', 'Offre'), ('demande', 'Demande')], max_length=10, verbose_name='type')),
                ('is_active', models.BooleanField(default=True, help_text="Détermine si la offre d'emploi est visible publiquement.", verbose_name='active')),
                ('description', wagtail.core.fields.RichTextField(default="\n        Pensez à présenter ou préciser :\n        <ul>\n        <li>l'employeur, son univers,</li>\n        <li>le travail proposé, le type de contrat, les qualités demandées,</li>\n        <li>les précisions sur l'organisation (lieux, horaires de travail).</li>\n        </ul>\n        ")),
                ('use_owner_geolocalisation', models.BooleanField(default=False, help_text="Détermine s'il faut utiliser la localisation de l'annonceur⋅se à la place, si elle est définie.", verbose_name="localisation de l'annonceur⋅se de l'offre d'emploi")),
                ('created_at', models.DateTimeField(blank=True, default=django.utils.timezone.now, editable=False, verbose_name='date de création')),
                ('last_modified_at', models.DateTimeField(blank=True, editable=False, verbose_name='date de la dernière modification')),
            ],
            options={
                'verbose_name': "offre d'emploi",
                'verbose_name_plural': "offres d'emplois",
                'permissions': (('contact_offreemploi', "Peut contacter les annonceurs⋅ses des offres d'emploi"),),
            },
            bases=(models.Model, wagtail.search.index.Indexed),
        ),
        migrations.CreateModel(
            name='OffreEmploiCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='nom')),
                ('slug', models.SlugField(max_length=80, unique=True)),
            ],
            options={
                'verbose_name': 'catégorie',
                'verbose_name_plural': "catégories des offres d'emplois",
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='UserOffreEmploiStats',
            fields=[
                ('account', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, related_name='offre_emploi_stats', serialize=False, to=settings.AUTH_USER_MODEL)),
                ('offre_emplois_nb', models.PositiveSmallIntegerField(default=0, help_text="Nombre total de offres d'emplois publiées.", verbose_name="nombre d'offres d'emploi")),
                ('messages_nb', models.PositiveSmallIntegerField(default=0, help_text="Nombre total de messages envoyés sur les offres d'emplois.", verbose_name='nombre de messages')),
            ],
        ),
        migrations.CreateModel(
            name='OffreEmploiPhoto',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('photo', stdimage.models.StdImageField(upload_to=dynamic_filenames.FilePattern(filename_pattern='offres_emploi/photos/{uuid:x}{ext}'))),
                ('title', models.CharField(blank=True, max_length=255, verbose_name='titre')),
                ('offre_emploi', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='photos', to='emplois.OffreEmploi')),
            ],
            options={
                'verbose_name': "photo d'une offre d'emploi",
                'verbose_name_plural': "photos d'une offre d'emploi",
                'ordering': ('offre_emploi', 'sort_order'),
            },
        ),
        migrations.AddField(
            model_name='offreemploi',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='emplois.OffreEmploiCategory', verbose_name='catégorie'),
        ),
        migrations.AddField(
            model_name='offreemploi',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='offres_emploi', to=settings.AUTH_USER_MODEL, verbose_name='annonceur⋅se'),
        ),
        migrations.CreateModel(
            name='EmploisSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('introduction', models.TextField(help_text="Un petit texte d'introduction pour décrire le service, affiché en haut de la page.")),
                ('last_offre_emplois_nb', models.PositiveSmallIntegerField(default=3, help_text="Le nombre de dernières offres d'emplois à afficher, ou 0 pour les masquer.", verbose_name="dernières offres d'emplois")),
                ('help_is_active', models.BooleanField(default=False, help_text="Définis si la page d'aide est visible.", verbose_name='aide active')),
                ('help_content', wagtail.core.fields.RichTextField(blank=True, verbose_name="contenu de l'aide")),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': "paramètres du service d'émplois",
            },
        ),
    ]
