from django.conf import settings
from django.core.mail import send_mail
from django.db.models.signals import post_save
from django.dispatch import Signal
from django.template.loader import render_to_string

from boiteaasso.accounts.models import UserAccount

from .models import OffreEmploi, UserOffreEmploiStats

offreemploi_created = Signal()


def post_save_emploi_stats(instance, created, **kwargs):
    """
    Incrémente le compteur de la personne lors d'une offre d'emploi.
    """
    if created:
        stats, stats_created = UserOffreEmploiStats.objects.get_or_create(
            account=instance.owner, defaults={'offre_emplois_nb': 1}
        )
        if not stats_created:
            stats.offre_emplois_nb += 1
            stats.save()


def offreemploi_created_notify(instance, request, **kwargs):
    """
    Notifie les administrateurs de la création d'une nouvelle annonce d'emploi
    en attente de modération.
    """
    to_emails = UserAccount.objects.admins().values_list('email', flat=True)
    if not to_emails:
        return

    context = {
        'annonce': instance,
        'protocol': request.scheme,
        'domain': request.get_host(),
    }
    subject = render_to_string(
        'emplois/emails/offreemploi_created_notify_subject.txt', context
    )
    subject = ''.join(subject.splitlines())
    message_txt = render_to_string(
        'emplois/emails/offreemploi_created_notify_email.txt', context
    )
    message_html = render_to_string(
        'emplois/emails/offreemploi_created_notify_email.html', context
    )

    send_mail(
        subject,
        message_txt,
        settings.DEFAULT_FROM_EMAIL,
        to_emails,
        html_message=message_html,
    )


def register_signal_handlers():
    post_save.connect(post_save_emploi_stats, sender=OffreEmploi)
    offreemploi_created.connect(offreemploi_created_notify)
