import pytest

from boiteaasso.accounts.tests_accounts.factories import (
    AssociationFactory,
    UserAccountFactory,
)

from .factories import OffreEmploiFactory


@pytest.mark.django_db
class TestOffreEmploiPermissionTester:
    def setup_method(self):
        self.offre_emploi = OffreEmploiFactory()

    def test_owner_permissions(self):
        tester = self.offre_emploi.permissions_for_user(self.offre_emploi.owner)
        assert tester.is_owner()
        assert tester.can_edit()
        assert tester.can_delete()
        assert not tester.can_contact()

    def test_association_permissions(self):
        tester = self.offre_emploi.permissions_for_user(
            AssociationFactory().account
        )
        assert not tester.is_owner()
        assert not tester.can_edit()
        assert not tester.can_delete()
        assert tester.can_contact()

    def test_user_permissions(self):
        tester = self.offre_emploi.permissions_for_user(UserAccountFactory())
        assert not tester.is_owner()
        assert not tester.can_edit()
        assert not tester.can_delete()
        assert not tester.can_contact()

    def test_admin_permissions(self):
        tester = self.offre_emploi.permissions_for_user(
            UserAccountFactory(
                permissions__codenames=[
                    'change_offreemploi',
                    'delete_offreemploi',
                ]
            )
        )
        assert not tester.is_owner()
        assert tester.can_edit()
        assert tester.can_delete()
        assert not tester.can_contact()
