from django.contrib.auth import get_user_model
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe

from wagtail.admin.panels import Panel

User = get_user_model()


class SubscriptionsPanel(Panel):
    class BoundPanel(Panel.BoundPanel):
        template = "formations/list_subscriptions.html"

        fields = [
            'name',
            'family_name',
            'email',
            'submit_time',
            'is_active',
            'user',
        ]

        def render_html(self, parent_context):
            subscriptions = self.instance.subscriptions.all()
            headings = [
                subscriptions.model._meta.get_field(f).verbose_name
                for f in self.fields
            ]
            values = subscriptions.values('id', *self.fields)
            rows = [
                (
                    obj['id'],
                    obj['is_active'],
                    [(k, obj[k]) for k in self.fields if k != 'user']
                    + [('user', str(User.objects.get(pk=obj['user'])))],
                )
                for obj in values
            ]
            mailto = ", ".join(
                [
                    '"{} {}" <{}>'.format(
                        s['name'], s['family_name'], s['email']
                    )
                    for s in values
                    if s['is_active']
                ]
            )
            return mark_safe(
                render_to_string(
                    self.template,
                    {'headings': headings, 'rows': rows, 'mailto': mailto},
                )
            )
