# Generated by Django 2.1.13 on 2019-10-08 17:26

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import dynamic_filenames
import location_field.models.plain
import modelcluster.fields
import stdimage.models
import wagtail.fields
import wagtail.search.index


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('wagtailcore', '0040_page_draft_title'),
    ]

    operations = [
        migrations.CreateModel(
            name='Formation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rue', models.CharField(max_length=100, verbose_name='rue')),
                ('ville', models.CharField(max_length=100, verbose_name='ville')),
                ('code_postal', models.CharField(max_length=5, verbose_name='code postal')),
                ('geolocalisation', location_field.models.plain.PlainLocationField(blank=True, help_text="Le marqueur est initié en fonction de l'adresse, déplacez le pour affiner la position. Vous pouvez zoomer ou dézoomer avec la molette de la souris.", max_length=63, verbose_name='géolocalisation')),
                ('title', models.CharField(max_length=255, verbose_name='titre')),
                ('goal', models.CharField(max_length=255, verbose_name='objectif')),
                ('is_active', models.BooleanField(default=True, help_text='Détermine si la formation est visible publiquement.', verbose_name='active')),
                ('description', wagtail.fields.RichTextField()),
                ('location', models.CharField(help_text='Nom commun du lieu de formation', max_length=255, verbose_name='lieu')),
                ('max_attendees', models.PositiveSmallIntegerField(default=0, help_text="Limite au delà de laquelle les inscrits sont placés en liste d'attente. Ignoré si nul.", verbose_name='nombre maximal de participants')),
                ('use_owner_geolocalisation', models.BooleanField(default=False, help_text="Détermine s'il faut utiliser la localisation de l'organisateur-trice à la place, si elle est définie.", verbose_name="localisation de l'organisateur-trice")),
                ('created_at', models.DateTimeField(blank=True, default=django.utils.timezone.now, editable=False, verbose_name='date de création')),
                ('last_modified_at', models.DateTimeField(blank=True, editable=False, verbose_name='date de la dernière modification')),
                ('ask_picture_right', models.BooleanField(default=False, help_text="Demander le droit à l'image", verbose_name="droit à l'image")),
                ('ask_association', models.BooleanField(default=False, help_text='Demander dans quelle association la personne est engagée', verbose_name='association')),
                ('ask_knowledges', models.BooleanField(default=False, help_text='Demander si la personne a des connaissance relatives à la formation', verbose_name='connaissances')),
                ('ask_wishes', models.BooleanField(default=False, help_text='Demander si la personne a des attentes relatives à la formation', verbose_name='attentes')),
                ('ask_questions', models.BooleanField(default=False, help_text='Demander si la personne a des questions au sujet de la formation', verbose_name='questions')),
            ],
            options={
                'permissions': (('subscribe_formation', "Peut s'inscrire aux formations"),),
            },
            bases=(models.Model, wagtail.search.index.Indexed),
        ),
        migrations.CreateModel(
            name='FormationCategory',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='nom')),
                ('slug', models.SlugField(max_length=80, unique=True)),
                ('icon', stdimage.models.StdImageField(blank=True, null=True, upload_to=dynamic_filenames.FilePattern(filename_pattern='formations/icons/{uuid:x}{ext}'), verbose_name='icon')),
            ],
            options={
                'verbose_name': 'catégorie',
                'verbose_name_plural': 'catégories des formations',
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='FormationDescription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('intitule', models.CharField(max_length=255, verbose_name='intitulé')),
                ('description', models.CharField(max_length=255, verbose_name='description')),
                ('formation', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='more_description', to='formations.Formation')),
            ],
            options={
                'ordering': ['sort_order'],
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FormationPicture',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('picture', stdimage.models.StdImageField(upload_to=dynamic_filenames.FilePattern(filename_pattern='formations/pictures/{uuid:x}{ext}'), verbose_name='image')),
                ('title', models.CharField(blank=True, max_length=255, verbose_name='titre')),
                ('formation', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='pictures', to='formations.Formation')),
            ],
            options={
                'verbose_name': "image d'une formation",
                'verbose_name_plural': "images d'une formation",
                'ordering': ('formation', 'sort_order'),
            },
        ),
        migrations.CreateModel(
            name='FormationsSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('introduction', models.TextField(help_text="Un petit texte d'introduction pour décrire le service, affiché en haut de la page.")),
                ('last_formations_nb', models.PositiveSmallIntegerField(default=3, help_text='Le nombre de dernières formations à afficher, ou 0 pour les masquer.', verbose_name='dernières formations')),
                ('help_is_active', models.BooleanField(default=False, help_text="Définis si la page d'aide est visible.", verbose_name='aide active')),
                ('help_content', wagtail.fields.RichTextField(blank=True, verbose_name="contenu de l'aide")),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'paramètres du service de formations',
            },
        ),
        migrations.CreateModel(
            name='FormationTimeRange',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('begin', models.DateTimeField(verbose_name='début')),
                ('end', models.TimeField(verbose_name='fin')),
                ('formation', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='ranges', to='formations.Formation')),
            ],
            options={
                'ordering': ['begin'],
            },
        ),
        migrations.CreateModel(
            name='Subscription',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rue', models.CharField(max_length=100, verbose_name='rue')),
                ('ville', models.CharField(max_length=100, verbose_name='ville')),
                ('code_postal', models.CharField(max_length=5, verbose_name='code postal')),
                ('geolocalisation', location_field.models.plain.PlainLocationField(blank=True, help_text="Le marqueur est initié en fonction de l'adresse, déplacez le pour affiner la position. Vous pouvez zoomer ou dézoomer avec la molette de la souris.", max_length=63, verbose_name='géolocalisation')),
                ('submit_time', models.DateTimeField(auto_now_add=True, verbose_name="date d'inscription")),
                ('is_active', models.BooleanField(default=False, verbose_name='inscription confirmée')),
                ('name', models.CharField(max_length=255, verbose_name='prénom')),
                ('family_name', models.CharField(max_length=255, verbose_name='nom')),
                ('email', models.EmailField(max_length=254, verbose_name='Courriel')),
                ('phone', models.CharField(max_length=255, verbose_name='téléphone')),
                ('picture_right', models.BooleanField(default=False, help_text="J'autorise l'organisateur de la formation de diffuser des images ou j'apparait.", verbose_name="droit à l'image")),
                ('association', models.CharField(blank=True, help_text="Si vous faites partie d'une association, indiquez laquelle.", max_length=255, null=True, verbose_name='association')),
                ('knowledges', models.TextField(blank=True, help_text='Avez vous des connaissances liées à la formation ?', null=True, verbose_name='connaissances')),
                ('wishes', models.TextField(blank=True, help_text='Quelles attentes avez vous sur la formation ?', null=True, verbose_name='attentes')),
                ('questions', models.TextField(blank=True, help_text="Avez vous des questions pour l'organisateur ?", null=True, verbose_name='questions')),
                ('formation', modelcluster.fields.ParentalKey(limit_choices_to={'is_active': True}, on_delete=django.db.models.deletion.CASCADE, related_name='subscriptions', to='formations.Formation')),
                ('user', models.ForeignKey(editable=False, limit_choices_to={'is_active': True}, on_delete=django.db.models.deletion.CASCADE, related_name='formation_subscriptions', to=settings.AUTH_USER_MODEL, verbose_name="Compte d'inscription")),
            ],
            options={
                'verbose_name': 'Inscription à une formation',
                'verbose_name_plural': 'Inscriptions à des formations',
            },
        ),
        migrations.AddField(
            model_name='formation',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='formations.FormationCategory', verbose_name='catégorie'),
        ),
        migrations.AddField(
            model_name='formation',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='formations', to=settings.AUTH_USER_MODEL, verbose_name='organisateur-trice'),
        ),
    ]
