from django.utils import timezone

from factory import Faker, RelatedFactory, Sequence, SubFactory
from factory.django import DjangoModelFactory

from boiteaasso.accounts.tests_accounts.factories import (
    AssociationUserAccountFactory,
    UserAccountFactory,
)

from ..models import (
    Formation,
    FormationCategory,
    FormationTimeRange,
    Subscription,
)


class FormationCategoryFactory(DjangoModelFactory):
    name = Sequence(lambda x: 'Catégorie {0}'.format(x))

    class Meta:
        model = FormationCategory


class FormationOrganiserAccountFactory(AssociationUserAccountFactory):
    permissions__codenames = (
        AssociationUserAccountFactory.permissions__codenames + ['access_admin']
    )


class FormationTimeRangeFactory(DjangoModelFactory):
    begin = Faker('future_datetime', tzinfo=timezone.utc)
    end = Faker('time')

    class Meta:
        model = FormationTimeRange


class FormationFactory(DjangoModelFactory):
    title = Faker('sentence', nb_words=5)
    description = Faker('text', max_nb_chars=200)
    category = SubFactory(FormationCategoryFactory)
    owner = SubFactory(FormationOrganiserAccountFactory)
    max_attendees = 12
    ask_questions = True

    when = RelatedFactory(
        FormationTimeRangeFactory,
        factory_related_name='formation',
    )

    class Meta:
        model = Formation


class SubscriptionFactory(DjangoModelFactory):
    name = Faker('first_name')
    family_name = Faker('last_name')
    email = Faker('email')
    phone = Faker('phone_number')

    rue = Faker('text', max_nb_chars=20)
    code_postal = Faker('postcode')
    ville = Faker('city')

    user = SubFactory(UserAccountFactory)
    formation = SubFactory(FormationFactory)

    questions = Faker('sentence', nb_words=20)

    class Meta:
        model = Subscription
