from django import template
from django.urls import reverse_lazy

from wagtailmenus.conf import settings as wagtailmenus_settings

register = template.Library()

SERVICES_MENU_ITEMS = [
    ("Échanges", reverse_lazy('echanges:annonces')),
    ("Emplois", reverse_lazy('emplois:offres_emplois')),
    ("Formations", reverse_lazy('formations:formations')),
]


def get_active_class(request, page_path, classes=None):
    """Retourne les classes pour un élément de menu.

    Détermine la classe la plus appropriée à appliquer pour un élément
    de menu, en fonction de son URL `page_path` et pour la requête. La
    classe sera retournée avec celles de la liste `classes`.
    """
    classes = set(classes or [])
    if request.path == page_path:
        classes.add(wagtailmenus_settings.ACTIVE_CLASS)
    if request.path.startswith(page_path) and page_path != '/':
        classes.add(wagtailmenus_settings.ACTIVE_ANCESTOR_CLASS)
    return ' '.join(classes)


@register.simple_tag(takes_context=True)
def services_item(context):
    return {
        'text': "Services",
        'href': '#',
        'active_class': get_active_class(
            context['request'],
            '{}/services/'.format(
                context['request'].META.get('SCRIPT_NAME', '').rstrip('/')
            ),
        ),
        'has_children_in_menu': True,
    }


@register.inclusion_tag('menus/main/sub_menu.html', takes_context=True)
def services_menu(context):
    menu_items = []
    for title, url in SERVICES_MENU_ITEMS:
        menu_items.append(
            {
                'text': title,
                'href': str(url),
                'active_class': get_active_class(context['request'], str(url)),
            }
        )
    return {'menu_items': menu_items}
