class cached_class_property:
    """
    Decorator that converts a method into a property cached on the class.

    Optional ``name`` argument allows you to make cached properties of other
    methods. (e.g.  url = cached_property(get_absolute_url, name='url') )
    """

    def __init__(self, func, name=None):
        self.func = func
        self.name = name or func.__name__

    def __get__(self, instance, cls):
        """
        Call the function and put the return value in class.__dict__ so that
        subsequent attribute access on the class returns the cached value
        instead of calling cached_class_property.__get__().
        """
        if instance is None:
            setattr(cls, self.name, self.func(cls))
        return getattr(cls, self.name)
