from django.conf import settings
from django.test.html import parse_html

import pytest


def parse_content(response, html=False):
    """
    Décode et retourne le contenu de la réponse, en le transformant en
    objet de structure Python si `html` vaut `True`.
    """
    if (
        hasattr(response, "render")
        and callable(response.render)
        and not response.is_rendered
    ):
        response.render()
    content = response.content.decode(response.charset)
    return parse_html(content) if html else content


def count_text_in_content(response, text, html=False):
    """
    Retourne le nombre d'occurrence de `text` dans le contenu de la réponse,
    en les analysant en tant que HTML si `html` vaut `True`.

    Cette méthode se base sur `django.test.SimpleTestCase.assertContains()`,
    et pourrait être remplacée après l'intégration de pytest-django#709.
    """
    content = parse_content(response, html=html)
    text = parse_html(text) if html else str(text)
    return content.count(text)


def log_in_client(client, user):
    """Tente d'authentifier le client avec un utilisateur donné."""
    user.set_password('password')
    user.save()
    return client.login(email=user.email, password='password')


skipif_sqlite = pytest.mark.skipif(
    'sqlite' in getattr(settings, 'DATABASES')['default']['ENGINE'],
    reason="Cannot run with sqlite backend",
)
