import unittest

from ..functional import cached_class_property


class FunctionalTest(unittest.TestCase):
    def test_cached_class_property(self):
        class A:
            @cached_class_property
            def value(self):
                return 1, object()

            def other_value(self):
                return 1

            other = cached_class_property(other_value, name='other')

        a = A()

        # check that it is cached
        self.assertEqual(a.value, a.value)

        # check that it returns the right thing
        self.assertEqual(a.value[0], 1)

        # check that state is shared between the class and the instance
        self.assertEqual(A.value, a.value)

        # check that overriding name works
        self.assertEqual(A.other, 1)
        self.assertTrue(callable(A.other_value))
